@@ -89,7 +89,7 @@ static void free_resolv_cb_data(struct resolv_cb_data *);
 
 
 void
-init_connections() {
+init_connections(void) {
     TAILQ_INIT(&connections);
 }
 
@@ -176,7 +176,7 @@ free_connections(struct ev_loop *loop) {
 
 /* dumps a list of all connections for debugging */
 void
-print_connections() {
+print_connections(void) {
     char filename[] = "/tmp/sniproxy-connections-XXXXXX";
 
     int fd = mkstemp(filename);
@@ -504,6 +504,10 @@ resolve_server_address(struct Connection *con, struct ev_loop *loop) {
             free((void *)result.address);
 
         abort_connection(con);
+        (void)loop;
+        (void)free_resolv_cb_data;
+        (void)resolv_cb;
+
         return;
 #else
         struct resolv_cb_data *cb_data = malloc(sizeof(struct resolv_cb_data));
